@@ -26,7 +26,7 @@ sub _indicator_config { _config()->{indicator} }
 #
 sub create {
 	my $ep = Wx::StyledTextCtrl->new( Kephra::App::Window::_ref() );
-	#$ep->DragAcceptFiles(1) if Wx::wxMSW();
+	$ep->DragAcceptFiles(1) if Wx::wxMSW();
 	_ref($ep);
 	return $ep;
 }
@@ -70,7 +70,7 @@ sub apply_settings {
 	$ep->SetScrollWidth($conf->{scroll_width}) 
 		unless $conf->{scroll_width} eq 'auto';
 	#wxSTC_CP_UTF8 Wx::wxUNICODE()
-	$ep->SetCodePage(65001);
+	$ep->SetCodePage(65001);#
 	set_word_chars();
 
 	# internal
