@@ -225,8 +225,8 @@ sub get {
 					'lf' => "Kephra::Document::convert_EOL('lf')",
 				},
 				move => {
-					left => 'Kephra::Document::move_left()',
-					right => 'Kephra::Document::move_right()',
+					left => 'Kephra::Document::Change::move_left()',
+					right => 'Kephra::Document::Change::move_right()',
 				},
 				readonly => {
 					'as-attr' => "Kephra::Document::set_readonly('protect')",
@@ -282,7 +282,7 @@ sub get {
 				tabs => {
 					hard => 'Kephra::Document::set_tabs_hard()',
 					soft => 'Kephra::Document::set_tabs_soft()',
-					'use' => 'Kephra::Document::switch_tab_mode()',
+					use => 'Kephra::Document::switch_tab_mode()',
 					width => {
 						1 => 'Kephra::Document::set_tab_size(1)',
 						2 => 'Kephra::Document::set_tab_size(2)',
@@ -743,7 +743,7 @@ sub get {
 			#use_file_type' => '1
 		},
 		key => {
-			'app-exit' => 'alt+f4',
+			'app-exit' => 'alt+q',
 			file => {
 				new => 'ctrl+n',
 				open => 'ctrl+o',
@@ -758,7 +758,7 @@ sub get {
 				print => 'ctrl+p',
 				close => {
 					current => 'ctrl+q',
-					all => 'alt+q',
+					all => 'ctrl+alt+q',
 					other => 'ctrl+shift+q',
 				},
 			},
