@@ -35,11 +35,11 @@ sub simple {
 	elsif ($v eq '2.6.3'){$sciv .= '1.62'}
 	elsif ($v eq '2.8.4'){$sciv .= '1.70'}
 	elsif ($v eq '2.8.7'){$sciv .= '1.70'}
-	my $content = "Perfect Coding Enviroment "
+	my $content = "Kephra, Nether of software creation\n"
 		. "$info->{mady_by}  Herbert Breunung\n\n"
 		. "$info->{licensed} GPL (GNU Public License) \n"
 		. " ( $info->{detail} \n   $info->{more} ) \n"
-		. "$info->{homepage}  http:\\\\proton-ce.sf.net\n\n"
+		. "$info->{homepage}  http://kephra.sf.net\n\n"
 		. "$info->{contains}: \n"
 		. " - Perl ". substr($],0,1).'.'.int(substr($],3,2)).'.'.substr($],7,1)."\n"
 		. " - WxPerl $Wx::VERSION $info->{wrappes} \n"
